@@ -158,11 +158,15 @@ class SpatialReference(GDALBase):
 
     def auth_name(self, target):
         "Return the authority name for the given string target node."
-        return capi.get_auth_name(self.ptr, force_bytes(target))
+        return capi.get_auth_name(
+            self.ptr, target if target is None else force_bytes(target)
+        )
 
     def auth_code(self, target):
         "Return the authority code for the given string target node."
-        return capi.get_auth_code(self.ptr, force_bytes(target))
+        return capi.get_auth_code(
+            self.ptr, target if target is None else force_bytes(target)
+        )
 
     def clone(self):
         "Return a clone of this SpatialReference object."
@@ -204,7 +208,7 @@ class SpatialReference(GDALBase):
     def srid(self):
         "Return the SRID of top-level authority, or None if undefined."
         try:
-            return int(self.attr_value("AUTHORITY", 1))
+            return int(self.auth_code(target=None))
         except (TypeError, ValueError):
             return None
 
