@@ -156,7 +156,10 @@ class Serializer(base.Serializer):
 
                 def queryset_iterator(obj, field):
                     return (
-                        getattr(obj, field.name).select_related().only("pk").iterator()
+                        getattr(obj, field.name)
+                        .select_related(None)
+                        .only("pk")
+                        .iterator()
                     )
 
             m2m_iter = getattr(obj, "_prefetched_objects_cache", {}).get(
